@@ -374,3 +374,13 @@ void ApiClient::scrobblerSubmissionReply(QString data)
 {
     emit scrobblerSubmissionData(data);
 }
+
+void ApiClient::setApiKey(QString apikey)
+{
+    api_key = apikey;
+}
+
+void ApiClient::setApiSecret(QString apisecret)
+{
+    api_secret = apisecret;
+}
