@@ -1,3 +1,13 @@
+/*
+ * utils.h -- Methods usefull to other classes
+ *
+ * Copyright (C) 2010 Andrea Grandi
+ * Authors: Andrea Grandi <a.grandi@gmail.com>
+ *
+ * This file is part of LastGo and is published under the GNU GPLv2
+ * See the README file for more details.
+ */
+
 #ifndef UTILS_H
 #define UTILS_H
 
@@ -18,6 +28,7 @@ public:
     QString getAuthToken(const QString username, const QString password);
     QString buildApiUrl(const QString baseurl, const QMap<QString, QString> params);
     QByteArray buildPostParameters(const QMap<QString, QString> params);
+    QString getScrobblerAuthToken(QString api_secret, QString timestamp);
 
 signals:
 
